## markdown-side-menu

<webc-container>
    <webc-api-side-menu         data_file='en/web-pages/dev/web-components/api/side-menu/small-menu.toml'></webc-api-side-menu>
    <webc-api-markdown-to-html  content_path='en/web-pages/demos/index.md'       ></webc-api-markdown-to-html>
    <webc-api-side-menu         data_file='en/web-pages/dev/web-components/api/side-menu/side-menu-1.toml'></webc-api-side-menu>
</webc-container>

